@@ -1,9 +1,9 @@
 package App::setop;
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 1;
-# ABSTRACT: Set operations (union, intersection, difference) on lines of files
+# ABSTRACT: Set operations (union, intersection, difference, symmetric diff) on lines of files
 
 __END__
 
@@ -13,11 +13,11 @@ __END__
 
 =head1 NAME
 
-App::setop - Set operations (union, intersection, difference) on lines of files
+App::setop - Set operations (union, intersection, difference, symmetric diff) on lines of files
 
 =head1 VERSION
 
-This document describes version 0.07 of App::setop (from Perl distribution App-setop), released on 2014-07-17.
+This document describes version 0.08 of App::setop (from Perl distribution App-setop), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -41,11 +41,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
